@@ -205,11 +205,8 @@ class Bundle(object):
                 visit(self.modules[o])
             elif o in self.entries:
                 visit(self.entries[o].module)
-#            elif isinstance(o, basestring) and o.startswith('http://')
-#                seen.add(o)
-#                include.add(RemoteModule(o))
             else:
-                RuntimeError("Cannot resolve dependancy: %r" % r)
+                RuntimeError("Cannot resolve dependancy: %r" % o)
         
         for name in require:
             visit(name)
@@ -306,7 +303,7 @@ class Bundle(object):
         module = Module(path, name)
         for match in self.section_match.findall( module.src ):
             self.process_section( module, match )
-        
+
         self.modules[module.name] = module
     
     def process_section(self, module, section):
@@ -324,11 +321,11 @@ class Bundle(object):
             entry = module.entry()
             lines.insert(0, name)
         else:
-            if '(' in name:
-                name, sig = name.split('(')
-                sig = '(' + sig
+            m = re.match(r'([\w\$\.]+)\s*(.*)', name)
+            if m:
+                name, sig = m.group(1).strip(), m.group(2).strip()
             else:
-                sig = None
+                sig = ''
             entry = module.entry(name, sig)
         
         for line in self.scanner(lines, section):
